pywurfl.algorithms

Package pywurfl :: Module algorithms |
[hide private]
[frames] | no frames]

# Module algorithms

source code
pywurfl search algorithms

Author: Armand Lynch <lyncha@users.sourceforge.net>

Copyright: Copyright 2006-2008, Armand Lynch

License: LGPL

Classes | [hide private]
| Algorithm Base class for all pywurfl search algorithms
| JaroWinkler Jaro-Winkler Search Algorithm
| LevenshteinDistance Levenshtein distance Search Algorithm
| Tokenizer Tokenizer Search Algorithm

Variables | [hide private]
| __doc__ = ``...``
| __url__ = ``'``http://celljam.net/``'``

Variables Details | [hide private]

  ### __doc__ Value:
      """
      pywurfl search algorithms
      """